"use strict";
var childProcess = require("child_process");
var portFinder = require("portfinder");
var path = require("path");
var utils_1 = require("./utils");
var opn = require("opn");
var lodash_1 = require("lodash");
var slim_typings_1 = require("./config/slim-typings");
var fs = require("fs");
var yargs_1 = require("yargs");
function getCurrentCommit() {
    if (fs.existsSync(path.join(process.cwd(), ".git"))) {
        return childProcess
            .execSync("git rev-parse HEAD")
            .toString().trim();
    }
    else {
        return "";
    }
}
var randomPort;
function getAvailablePort() {
    if (randomPort) {
        return Promise.resolve(randomPort);
    }
    else {
        if (yargs_1.argv["ci"]) {
            randomPort = 2048 + Math.round(Math.random() * 60000);
            return Promise.resolve(randomPort);
        }
        else {
            return portFinder.getPortPromise();
        }
    }
}
exports.getAvailablePort = getAvailablePort;
function openBrowser(host, port, baseHref) {
    if (baseHref === void 0) { baseHref = "/"; }
    return opn("http://" + host + ":" + port + baseHref);
}
exports.openBrowser = openBrowser;
function getEnvironment(rootDir) {
    var environment = process.env.NODE_ENV || "development";
    var pkg = getPackage(rootDir);
    var version = JSON.stringify(pkg["version"] || "unknown");
    var commit = JSON.stringify(getCurrentCommit());
    var buildDate = JSON.stringify(new Date());
    var properties = pkg["buildProperties"] ? pkg.buildProperties[yargs_1.argv["env"] ? yargs_1.argv["env"] : environment] : {};
    Object.keys(properties).forEach(function (prop) { return properties[prop] = JSON.stringify(properties[prop]); });
    return Object.assign({}, properties, { version: version, commit: commit, buildDate: buildDate, current: JSON.stringify(environment) });
}
exports.getEnvironment = getEnvironment;
function getSlimConfig(rootDir) {
    var config = slim_typings_1.defaultSlimConfig;
    var slimConfigPath = path.join(rootDir, "slim.config.ts");
    if (fs.existsSync(slimConfigPath)) {
        var projectSlimConfig = require(slimConfigPath);
        config = lodash_1.merge(config, projectSlimConfig);
        if (Array.isArray(projectSlimConfig.sass.importsIgnoredDuringTesting)) {
            config.sass.importsIgnoredDuringTesting = projectSlimConfig.sass.importsIgnoredDuringTesting;
        }
    }
    else {
        utils_1.logger.debug("Did not find a slim.config.ts file in the current directory.");
    }
    utils_1.logger.debug("slim.config.ts:\n" + JSON.stringify(config, null, 2));
    return normalizeConfig(config);
}
exports.getSlimConfig = getSlimConfig;
function prettyPrintConfig(webpackConfig) {
    var replacerFn = function (key, value) {
        // Filter webpack.DllReferencePlugin manifest entries
        if (value && value["options"] !== undefined && value["options"]["context"] !== undefined) {
            return undefined;
        }
        return value;
    };
    return JSON.stringify(webpackConfig, replacerFn, 2);
}
exports.prettyPrintConfig = prettyPrintConfig;
function normalizeConfig(config) {
    config.sourceDir = path.join(config.rootDir, config.sourceDir);
    config.targetDir = path.join(config.rootDir, config.targetDir);
    config.dllDir = path.join(config.rootDir, config.dllDir);
    config.coverageDir = path.join(config.rootDir, config.coverageDir);
    config.typescript.entry = path.join(config.sourceDir, config.typescript.entry);
    config.angular.aotTsConfig = path.join(config.rootDir, config.angular.aotTsConfig);
    config.angular.appModule = path.join(config.rootDir, config.angular.appModule);
    config.sass.includePaths.push(config.sourceDir);
    config.sass.globalStyles = config.sass.globalStyles.map(function (style) { return path.isAbsolute(style) ? style : path.join(config.rootDir, style); });
    for (var _i = 0, _a = config.assets.entries; _i < _a.length; _i++) {
        var asset = _a[_i];
        if (!path.isAbsolute(asset.from)) {
            asset.from = path.join(config.rootDir, asset.from);
        }
    }
    return config;
}
function getPackage(rootDir) {
    var pkg;
    try {
        pkg = require(path.join(rootDir, "package.json"));
    }
    catch (error) {
        console.error(error);
        pkg = {};
    }
    return pkg;
}
exports.getPackage = getPackage;
//# sourceMappingURL=cli-helpers.js.map