"use strict";
var yargs = require("yargs");
var readline = require("readline");
var dev_command_1 = require("./commands/dev.command");
var build_command_1 = require("./commands/build.command");
var test_command_1 = require("./commands/test.command");
var e2e_command_1 = require("./commands/e2e.command");
var publish_command_1 = require("./commands/publish.command");
var release_command_1 = require("./commands/release.command");
var new_command_1 = require("./commands/new.command");
var chalk = require("chalk");
var path = require("path");
var doc_command_1 = require("./commands/doc.command");
var fs = require("fs");
var os = require("os");
var child_process_1 = require("child_process");
var utils_1 = require("./utils");
var yargs_1 = require("yargs");
function main() {
    var pkg = require(path.join(__dirname, "..", "package.json"));
    var rl = readline.createInterface({
        input: process.stdin,
        output: process.stdout
    });
    rl.on("SIGINT", function () {
        process.exit(0);
    });
    if (!yargs_1.argv["ci"]) {
        var slimPath = path.join(os.homedir(), ".slim");
        var metadataPath = path.join(slimPath, ".metadata.json");
        var slimMetadata = void 0;
        if (!fs.existsSync(slimPath)) {
            fs.mkdirSync(slimPath);
            slimMetadata = {};
        }
        else {
            if (fs.existsSync(metadataPath)) {
                slimMetadata = require(metadataPath);
            }
            else {
                slimMetadata = {};
            }
        }
        if (!slimMetadata.lastVersionUpdateCheck || new Date().getTime() - new Date(slimMetadata.lastVersionUpdateCheck).getTime() > 1000 * 60 * 60 * 24) {
            checkForUpdate(pkg, metadataPath, slimMetadata);
        }
    }
    yargs
        .locale("en")
        .version(pkg.version)
        .usage("Usage: $0 <command> [options]")
        .command(new_command_1.newCommand)
        .command(dev_command_1.devCommand)
        .command(build_command_1.buildCommand)
        .command(test_command_1.testCommand)
        .command(e2e_command_1.e2eCommand)
        .command(doc_command_1.docCommand)
        .command(release_command_1.releaseCommand)
        .command(publish_command_1.publishCommand)
        .alias("h", "help")
        .alias("v", "version")
        .option("environment", {
        alias: "env",
        description: "Use the buildProperties of a different environment from the package.json than defined via NODE_ENV."
    })
        .option("ci", {
        description: "Run slim in a Continuous Integration environment mode. This produces file outputs for tests and reduces logging."
    })
        .demand(1)
        .epilog("Run " + chalk.bold("$0 <command> --help") + " for more information on the specific command.")
        .help().argv;
}
exports.main = main;
function checkForUpdate(pkg, metadataPath, slimMetadata) {
    utils_1.logger.debug("Checking for newer slim version...");
    return getLatestSlimVersion(pkg).then(function (version) {
        if (pkg.version !== version) {
            console.log("\n");
            utils_1.logger.info("---------------- UPDATE AVAILABLE! ----------------");
            utils_1.logger.info("There is a new version of slim available! Current version: " + pkg.version + ". Latest version: " + version + ".");
            utils_1.logger.info("Run " + chalk.bold("npm i -g slim-cli") + " to update.");
            console.log("\n");
        }
        slimMetadata.lastVersionUpdateCheck = new Date();
        fs.writeFileSync(metadataPath, JSON.stringify(slimMetadata, null, 4));
    });
}
function getLatestSlimVersion(pkg) {
    return new Promise(function (resolve) {
        var npmCommand = child_process_1.spawn("npm", ["show", pkg.name, "version"]);
        npmCommand.stdout.on("data", function (version) {
            resolve(version.toString().trim());
        });
    });
}
//# sourceMappingURL=cli.js.map