"use strict";
var cli_helpers_1 = require("../cli-helpers");
exports.buildCommand = {
    command: "build",
    describe: "Bundle the application using webpack and put the result in the targetDir (default: www) of the project.",
    builder: {
        "minify": {
            alias: "m",
            type: "boolean",
            description: "Use UglifyJS to minify the bundle."
        },
        "aot": {
            type: "boolean",
            description: "Use the Angular AOT compiler."
        },
        "serve": {
            type: "boolean",
            alias: "s",
            description: "Serve the application after it was built."
        }
    },
    handler: function (options) {
        var rootDir = process.cwd();
        var slimConfig = cli_helpers_1.getSlimConfig(rootDir);
        var environmentVariables = cli_helpers_1.getEnvironment(rootDir);
        var exitCode;
        var buildTask = require("../tasks/build.task");
        var serveTask = require("../tasks/serve.task");
        if (options.serve) {
            exitCode = buildTask(environmentVariables, slimConfig, options.minify, options.aot).then(function () { return serveTask(environmentVariables, slimConfig, options.open); });
        }
        else {
            exitCode = buildTask(environmentVariables, slimConfig, options.minify, options.aot);
        }
        exitCode
            .then(function (code) {
            process.exit(code);
        })
            .catch(function (code) {
            process.exit(code);
        });
    }
};
//# sourceMappingURL=build.command.js.map