"use strict";
var cli_helpers_1 = require("../cli-helpers");
exports.devCommand = {
    command: "dev",
    describe: "Start a development server.",
    builder: {
        "open": {
            alias: "o",
            type: "boolean",
            description: "Automatically open the web browser."
        },
        "update-dlls": {
            alias: "u",
            type: "boolean",
            description: "Create dynamically linked libraries for vendors (@angular/core, etc.) and polyfills. This has to be run after the dependencies have been updated."
        },
        "aot": {
            type: "boolean",
            description: "Use the Angular AOT compiler."
        }
    },
    handler: function (options) {
        var dllTask = require("../tasks/dll.task");
        var devTask = require("../tasks/dev.task");
        var rootDir = process.cwd();
        var slimConfig = cli_helpers_1.getSlimConfig(rootDir);
        var environmentVariables = cli_helpers_1.getEnvironment(rootDir);
        return dllTask(environmentVariables, slimConfig, options["update-dlls"])
            .then(function () { return devTask(environmentVariables, slimConfig, options.open, options.aot); })
            .then(function (code) {
            process.exit(code);
        })
            .catch(function (code) {
            process.exit(code);
        });
    }
};
//# sourceMappingURL=dev.command.js.map