"use strict";
var cli_helpers_1 = require("../cli-helpers");
exports.e2eCommand = {
    command: "e2e",
    describe: "Run the E2E tests.",
    builder: {
        "skip-build": {
            type: "boolean",
            description: "Use the last build for the E2E test."
        },
        "skip-update": {
            type: "boolean",
            description: "Do not update the webdriver binaries."
        },
        "specs": {
            type: "string",
            description: "Only run the these E2E tests."
        }
    },
    handler: function (options) {
        var e2eTask = require("../tasks/e2e.task");
        var serveTask = require("../tasks/serve.task");
        var buildTask = require("../tasks/build.task");
        var rootDir = process.cwd();
        var slimConfig = cli_helpers_1.getSlimConfig(rootDir);
        var environmentVariables = cli_helpers_1.getEnvironment(rootDir);
        (options["skip-build"] === true ? Promise.resolve(0) : buildTask(environmentVariables, slimConfig, options.minify, options.aot))
            .then(function () { return cli_helpers_1.getAvailablePort(); })
            .then(function (port) { return serveTask(environmentVariables, slimConfig, options.open, port, true); })
            .then(function (port) { return e2eTask(environmentVariables, slimConfig, port, options["skip-update"], options.specs); })
            .then(function (code) {
            process.exit(code);
        })
            .catch(function (code) {
            process.exit(code);
        });
    }
};
//# sourceMappingURL=e2e.command.js.map