"use strict";
var utils_1 = require("../utils");
var path = require("path");
var os = require("os");
var fs = require("fs");
var builder = (function () {
    var templates = {
        "portal": {
            alias: "p",
            type: "boolean",
            description: "Create a portal project.",
            url: "https://github.com/0xE282B0/slim-test-template"
        },
        "app": {
            alias: "a",
            type: "boolean",
            description: "Create an app project.",
            url: "https://github.com/0xE282B0/slim-app-template"
        }
    };
    try {
        var conf = path.join(os.homedir(), ".slim/templates.ts");
        if (fs.existsSync(conf)) {
            templates = require(conf).templates;
        }
        else {
            utils_1.logger.debug("No user config found in " + conf);
        }
    }
    catch (error) {
        utils_1.logger.info(error);
    }
    //TODO: (0xe282b0) check that templates variable is a valid CommandBuilder;
    //TODO: (0xe282b0) check that aliases are unique;
    return templates;
})();
exports.newCommand = {
    command: "new",
    builder: builder,
    handler: function (options) {
        // logger.info(options);
        //TODO: (0xe282b0): only if not a single option is selected
        var inquirer = require("inquirer");
        inquirer.prompt([
            {
                type: "list",
                name: "project.type",
                message: "What do you want to create?",
                choices: Object.keys(builder)
            }
        ]).then(function (answers) {
            var fs = require("fs");
            var targetPath = path.join(os.homedir(), ".slim", answers.project.type);
            if (fs.existsSync(targetPath)) {
                var simpleGit = require("simple-git")(targetPath);
                simpleGit.pull("origin", "master", { "--rebase": "true" })
                    .then(function () { return scaffold(targetPath, process.cwd()); }, function () { utils_1.logger.error("error"); });
                utils_1.logger.debug("check if local availabe");
                utils_1.logger.debug("pull if availabe");
            }
            else {
                var simpleGit_1 = require("simple-git")();
                utils_1.logger.debug("clone if not available");
                simpleGit_1.clone(builder[answers.project.type].url, targetPath)
                    .then(function () { return scaffold(targetPath, process.cwd()); });
            }
        });
    }
};
var scaffold = function (source, target) {
    var _ = require("lodash");
    var glob = require("glob");
    var templateConfig = require(path.join(source, "template.ts")).config;
    var inquirer = require("inquirer");
    inquirer.prompt(templateConfig.questions)
        .then(function (answers) { return new Promise(function (resolve, jeject) { return resolve(templateConfig.transformAnswers(answers)); }); })
        .then(function (answers) { return new Promise(function (resolve, reject) {
        glob("**", { cwd: source, ignore: templateConfig.include }, function (er, files) {
            for (var _i = 0, files_1 = files; _i < files_1.length; _i++) {
                var f = files_1[_i];
                var sourcePath = path.join(source, f);
                var targetPath = path.join(target, f);
                if (fs.lstatSync(sourcePath).isDirectory()) {
                    if (!fs.existsSync(targetPath)) {
                        fs.mkdirSync(targetPath);
                    }
                    continue;
                }
                utils_1.logger.debug(f);
                fs.createReadStream(path.join(source, f)).pipe(fs.createWriteStream(path.join(target, f)));
            }
            glob(templateConfig.include, { cwd: source }, function (er, files) {
                for (var _i = 0, files_2 = files; _i < files_2.length; _i++) {
                    var f = files_2[_i];
                    var sourcePath = path.join(source, f);
                    var targetPath = _.template(path.join(target, f))(answers);
                    if (fs.lstatSync(sourcePath).isDirectory()) {
                        if (!fs.existsSync(targetPath)) {
                            fs.mkdirSync(targetPath);
                        }
                        continue;
                    }
                    utils_1.logger.debug(f);
                    fs.writeFile(targetPath, _.template(fs.readFileSync(path.join(source, f), { "encoding": "utf8" }))(answers), function (err) {
                        if (err) {
                            return utils_1.logger.debug(err);
                        }
                    });
                }
                resolve(0);
            });
        });
    }); });
    // logger.debug("Read template.js");
    // logger.debug("Check if description is complete");
    // logger.debug("run before scaffolding script (check deps)");
    // logger.debug("ask questions");
    // logger.debug("replace placeholders");
    // logger.debug("run after scaffolding script");
};
//# sourceMappingURL=new.command.js.map