"use strict";
var chalk = require("chalk");
var cli_helpers_1 = require("../cli-helpers");
var utils_1 = require("../utils");
var path = require("path");
exports.testCommand = {
    command: "test",
    describe: "Run the unit tests.",
    builder: {
        "watch": {
            alias: "w",
            type: "boolean",
            description: "Watch the test und project files and re-run the unit tests on change."
        },
        "coverage": {
            type: "boolean",
            alias: "c",
            description: "Create coverage report."
        },
        "browsers": {
            type: "string",
            alias: "b",
            description: "Comma separated list of browsers to run the tests in. Example: " + chalk.bold("chrome,firefox,safari") + ". Default is " + chalk.bold("chrome") + "."
        },
        "xml-report": {
            type: "string",
            description: "Create a xml junit report and save it to the specified file."
        }
    },
    handler: function (options) {
        var dllTask = require("../tasks/dll.task");
        var testTask = require("../tasks/test.task");
        var rootDir = process.cwd();
        var slimConfig = cli_helpers_1.getSlimConfig(rootDir);
        var environmentVariables = cli_helpers_1.getEnvironment(rootDir);
        var browsers = parseBrowsers(options.browsers);
        if (!options.watch) {
            utils_1.timer.start("Running the unit tests");
        }
        return (options.ci ? Promise.resolve(0) : dllTask(environmentVariables, slimConfig, options["update-dlls"]))
            .then(function () { return testTask(environmentVariables, slimConfig, options.watch, options.ci ? true : options.coverage, browsers, options.ci ? path.join("test-reports", "unit-test-results.xml") : options["xml-report"]); })
            .then(function (code) {
            process.exit(code);
        })
            .catch(function (code) {
            process.exit(code);
        });
    }
};
function parseBrowsers(browserOption) {
    return typeof browserOption === "string" ? browserOption.split(",").map(function (option) { return option.charAt(0).toUpperCase().concat(option.substr(1)); }) : ["Chrome"];
}
//# sourceMappingURL=test.command.js.map