"use strict";
var path = require("path");
var yargs_1 = require("yargs");
function getKarmaConfig(testFilePattern, vendorsPattern, polyfillsPattern, port, watch, coverage, coverageDir, webpackConfig, browsers, xmlReport, stylePatterns) {
    var config = {
        basePath: "",
        frameworks: ["jasmine"],
        exclude: [],
        preprocessors: {},
        logLevel: "INFO",
        captureConsole: true,
        webpack: webpackConfig,
        webpackMiddleware: yargs_1.argv["debug"] ? {} : {
            stats: "errors-only",
            quiet: true
        },
        files: [
            {
                pattern: testFilePattern,
                watched: false,
            }
        ],
        coverageReporter: {
            type: "in-memory"
        },
        remapCoverageReporter: {
            json: path.join(coverageDir, "coverage.json"),
            html: path.join(coverageDir, "html")
        },
        processKillTimeout: 5000,
        junitReporter: {
            outputFile: xmlReport,
        },
        reporters: [
            "mocha",
            "kjhtml"
        ],
        client: {
            clearContext: false
        },
        port: port,
        colors: true,
        autoWatch: watch,
        browsers: yargs_1.argv["ci"] ? ["karma-detect-browsers"] : browsers,
        singleRun: !watch,
        mochaReporter: {
            output: "autowatch"
        },
        detectBrowsers: {
            usePhantomJS: false
        }
    };
    config.preprocessors[testFilePattern] = [
        "coverage",
        "webpack",
        "sourcemap"
    ];
    if (yargs_1.argv["ci"]) {
        config.frameworks.unshift("detectBrowsers");
    }
    else {
        config.files.unshift({
            pattern: polyfillsPattern,
            watched: false
        }, {
            pattern: vendorsPattern,
            watched: false
        });
    }
    if (Array.isArray(stylePatterns) && stylePatterns.length > 0) {
        stylePatterns.forEach(function (pattern) {
            config.files.push({
                pattern: pattern,
                watched: false
            });
            config.preprocessors[pattern] = ["webpack"];
        });
    }
    if (xmlReport) {
        config.reporters.push("junit");
    }
    if (coverage) {
        config.reporters.push("coverage", "remap-coverage");
    }
    return config;
}
exports.getKarmaConfig = getKarmaConfig;
//# sourceMappingURL=karma.conf.js.map