"use strict";
var path = require("path");
var webpack = require("webpack");
var webpackMerge = require("webpack-merge");
var rimraf = require("rimraf");
var webpack_config_common_1 = require("../webpack/webpack.config.common");
var webpack_config_build_1 = require("../webpack/webpack.config.build");
var utils_1 = require("../utils");
var cli_helpers_1 = require("../cli-helpers");
module.exports = function (env, config, minify, aot) {
    rimraf.sync(config.targetDir);
    utils_1.logger.debug("Deleted " + config.targetDir);
    var indexPath = path.join(config.sourceDir, "index.html");
    var commonConfig = webpack_config_common_1.getCommonConfigPartial(indexPath, env, config, false, aot);
    var buildConfig = webpack_config_build_1.getBuildConfigPartial(config, minify, indexPath);
    var webpackConfig = webpackMerge.smart(commonConfig, buildConfig);
    utils_1.logger.debug("Created webpack build config.", cli_helpers_1.prettyPrintConfig(webpackConfig));
    utils_1.logger.info("Building " + (minify ? "minified " : "") + "application" + (aot ? " using the Angular AOT compiler" : "") + "...");
    return runBuild(webpackConfig);
};
function runBuild(config) {
    utils_1.timer.start("Application build");
    return new Promise(function (resolve, reject) {
        webpack(config, function (error, stats) {
            if (error) {
                utils_1.logger.error(error);
                return reject(1);
            }
            if (!stats) {
                return reject(1);
            }
            else if (stats.hasErrors()) {
                var jsonStats = stats.toJson();
                if (jsonStats.errors && jsonStats.errors.length > 0) {
                    utils_1.logger.error(jsonStats.errors[0]);
                }
                return reject(1);
            }
            utils_1.timer.end("Application build");
            resolve(0);
        });
    });
}
//# sourceMappingURL=build.task.js.map