"use strict";
var WebpackDevServer = require("webpack-dev-server");
var webpackMerge = require("webpack-merge");
var webpack = require("webpack");
var path = require("path");
var webpack_config_common_1 = require("../webpack/webpack.config.common");
var webpack_config_dev_1 = require("../webpack/webpack.config.dev");
var cli_helpers_1 = require("../cli-helpers");
var utils_1 = require("../utils");
var chalk = require("chalk");
var readline = require("readline");
module.exports = function (env, config, open, aot) {
    return cli_helpers_1.getAvailablePort().then(function (port) {
        var webpackConfig = createWebpackDevConfig(env, config, port, aot);
        var compiler = webpack(webpackConfig);
        utils_1.logger.info("Started webpack development server at port " + port + ".");
        utils_1.logger.info("Go to " + chalk.underline("http://localhost:" + port) + " to view the application.");
        var server = new WebpackDevServer(compiler, webpackConfig.devServer);
        return startServer(server, port, open, config.baseHref);
    });
};
function createWebpackDevConfig(env, config, port, aot) {
    var indexPath = path.join(config.sourceDir, "index.html");
    var commonConfig = webpack_config_common_1.getCommonConfigPartial(indexPath, env, config, false, aot);
    var devConfig = webpack_config_dev_1.getDevConfigPartial(config, indexPath, aot, port);
    var webpackConfig = webpackMerge.smart(commonConfig, devConfig);
    utils_1.logger.debug("Created webpack development config.", cli_helpers_1.prettyPrintConfig(webpackConfig));
    return webpackConfig;
}
function startServer(server, port, open, baseHref) {
    var rl = readline.createInterface({
        input: process.stdin,
        output: process.stdout
    });
    return new Promise(function (resolve, reject) {
        var s = server.listen(port);
        s.on("close", function () {
            resolve(0);
        });
        if (open) {
            utils_1.logger.debug("Opening browser at " + ("http://localhost:" + port + baseHref + "."));
            cli_helpers_1.openBrowser("localhost", port, baseHref);
        }
        else {
            var timeout_1 = setTimeout(function () {
                utils_1.logger.debug("Did not receive enter key. Closing input stream.");
                rl.close();
            }, 10000);
            rl.question("================> Press enter during the next 10s to open the browser...\n", function () {
                clearTimeout(timeout_1);
                rl.close();
                cli_helpers_1.openBrowser("localhost", port, baseHref);
            });
        }
    });
}
//# sourceMappingURL=dev.task.js.map