"use strict";
var path = require("path");
var child_process_1 = require("child_process");
var utils_1 = require("../utils");
module.exports = function (env, config, port, skipWebDriverUpdate, specs) {
    return (skipWebDriverUpdate ? Promise.resolve(0) : webDriverUpdate()).then(function (exitCode) {
        if (exitCode === 0) {
            var specPaths = path.join(config.e2eDir, "**", "*.e2e.ts");
            if (specs) {
                specPaths = specs.split(",").map(function (spec) { return path.resolve(path.join(__dirname, "..", "config"), path.join(config.rootDir, spec)); }).join(",");
            }
            return runProtractor(port, specPaths);
        }
        else {
            return exitCode;
        }
    });
};
function getProtractorDir() {
    var result = require.resolve("protractor");
    if (result) {
        // result is now something like
        // c:\\Source\\gulp-protractor\\node_modules\\protractor\\lib\\protractor.js
        return path.resolve(path.join(path.dirname(result), "..", "..", ".bin"));
    }
    throw new Error("No protractor installation found.");
}
function getProtractorBinaryPath(binaryName) {
    var winExt = /^win/.test(process.platform) ? ".cmd" : "";
    return path.join(getProtractorDir(), binaryName + winExt);
}
function webDriverUpdate() {
    return new Promise(function (resolve) {
        var wdProcess = child_process_1.spawn(getProtractorBinaryPath("webdriver-manager"), ["update"], { stdio: "inherit" });
        wdProcess.on("close", function (exitCode) {
            resolve(exitCode);
        });
    });
}
function runProtractor(port, specs) {
    return new Promise(function (resolve) {
        var configPath = path.resolve("/", path.join(__dirname, "..", "config", "protractor.conf.js"));
        utils_1.logger.debug("Running the following command: protractor " + configPath + " --specs " + specs);
        var protractorProcess = child_process_1.spawn(getProtractorBinaryPath("protractor"), [configPath, "--specs", specs, "--baseUrl", "http://localhost:" + port], { stdio: "inherit" });
        protractorProcess.on("close", function (exitCode) {
            resolve(exitCode);
        });
    });
}
//# sourceMappingURL=e2e.task.js.map