"use strict";
var utils_1 = require("../../utils");
/**
 * Plugin to add script tags for the dll libraries to the processed html file.
 */
var DllTagPlugin = (function () {
    function DllTagPlugin(dllLibs) {
        if (dllLibs === void 0) { dllLibs = []; }
        this.dllLibs = dllLibs;
    }
    DllTagPlugin.prototype.apply = function (compiler) {
        var _this = this;
        compiler.plugin("compilation", function (compilation) {
            compilation.plugin("html-webpack-plugin-alter-asset-tags", function (htmlPluginData, callback) {
                if (!htmlPluginData.head) {
                    htmlPluginData.head = [];
                }
                _this.dllLibs.forEach(function (lib) {
                    var libScript = lib + ".dll.js";
                    htmlPluginData.head.push({
                        tagName: "script",
                        closeTag: true,
                        attributes: {
                            src: libScript,
                            type: "text/javascript"
                        }
                    });
                    utils_1.logger.debug("Added script tag for " + libScript + " to index.html.");
                });
                callback(null, htmlPluginData);
            });
        });
    };
    return DllTagPlugin;
}());
exports.DllTagPlugin = DllTagPlugin;
//# sourceMappingURL=dll-tags.plugin.js.map