"use strict";
var utils_1 = require("../../utils");
/**
 * Plugin to remove script tags with specific `src` attributes
 * from the processed html files.
 *
 * One example is the `cordova.js` file
 * that is only available in a Cordova environment and can be
 * ignored during development in the browser.
 */
var RemoveScriptsPlugin = (function () {
    function RemoveScriptsPlugin(scripts) {
        if (scripts === void 0) { scripts = []; }
        this.scripts = scripts;
    }
    RemoveScriptsPlugin.prototype.apply = function (compiler) {
        var _this = this;
        compiler.plugin("compilation", function (compilation) {
            compilation.plugin("html-webpack-plugin-before-html-processing", function (htmlPluginData, callback) {
                for (var _i = 0, _a = _this.scripts; _i < _a.length; _i++) {
                    var script = _a[_i];
                    var regex = new RegExp("<script.+src=\"" + script + "\".*?<\/script>");
                    if (regex.test(htmlPluginData.html)) {
                        htmlPluginData.html = htmlPluginData.html.replace(regex, "");
                        utils_1.logger.debug("Removed " + script + " from index.html.");
                    }
                }
                callback(null, htmlPluginData);
            });
            compilation.plugin("html-webpack-plugin-alter-asset-tags", function (htmlPluginData, callback) {
                if (htmlPluginData.body && Array.isArray(htmlPluginData.body)) {
                    htmlPluginData.body = htmlPluginData.body.filter(function (asset) {
                        for (var _i = 0, _a = _this.scripts; _i < _a.length; _i++) {
                            var script = _a[_i];
                            var regex = new RegExp(script);
                            if (asset.attributes && typeof asset.attributes.src === "string") {
                                if (regex.test(asset.attributes.src)) {
                                    utils_1.logger.debug("Removed " + script + " from index.html.");
                                    return false;
                                }
                            }
                        }
                        return true;
                    });
                }
                callback(null, htmlPluginData);
            });
        });
    };
    return RemoveScriptsPlugin;
}());
exports.RemoveScriptsPlugin = RemoveScriptsPlugin;
//# sourceMappingURL=remove-scripts.plugin.js.map