"use strict";
var webpack = require("webpack");
var CopyWebpackPlugin = require("copy-webpack-plugin");
var HtmlWebpackPlugin = require("html-webpack-plugin");
var suppress_chunks_webpack_plugin_1 = require("suppress-chunks-webpack-plugin");
var ExtractTextPlugin = require("extract-text-webpack-plugin");
var remove_scripts_plugin_1 = require("./plugins/remove-scripts.plugin");
var yargs_1 = require("yargs");
var path = require("path");
function getBuildConfigPartial(config, minify, indexPath) {
    var plugins = [
        new HtmlWebpackPlugin({
            template: indexPath
        }),
        new CopyWebpackPlugin(config.assets.entries),
        new suppress_chunks_webpack_plugin_1.default([
            { name: "styles", match: /\.js/ }
        ]),
        new remove_scripts_plugin_1.RemoveScriptsPlugin(["styles.js"]),
        new ExtractTextPlugin("styles.css"),
        new webpack.optimize.CommonsChunkPlugin({
            name: "vendor",
            chunks: ["app"],
            minChunks: function (module) { return module.resource && module.resource.startsWith(path.join(config.rootDir, "node_modules")); }
        })
    ];
    if (minify) {
        plugins.push(new webpack.optimize.UglifyJsPlugin({
            beautify: false,
            comments: false,
            mangle: { screw_ie8: true },
            compress: {
                screw_ie8: true,
                warnings: yargs_1.argv["debug"],
                sequences: true,
                dead_code: true,
                conditionals: true,
                comparisons: true,
                drop_debugger: true,
                evaluate: true,
                loops: true,
                booleans: true,
                unused: true,
                if_return: true,
                join_vars: true
            },
            sourceMap: true
        }));
    }
    var conf = {
        bail: true,
        stats: yargs_1.argv["ci"] ? "errors-only" : "minimal",
        devtool: "source-map",
        plugins: plugins,
        module: {
            rules: [
                {
                    test: /\.scss$/,
                    exclude: /\.style\.scss$/,
                    use: ExtractTextPlugin.extract({
                        use: [
                            {
                                loader: "css-loader",
                                options: {
                                    importLoaders: 1,
                                    localIdentName: "[name]"
                                }
                            },
                            {
                                loader: "postcss-loader",
                                options: {
                                    config: path.resolve(__dirname, "..", "config")
                                }
                            },
                            {
                                loader: "sass-loader",
                                options: {
                                    sourceMap: false,
                                    includePaths: config.sass.includePaths,
                                    outputStyle: config.sass.outputStyle
                                }
                            },
                            "empty-sass-shim-loader"
                        ]
                    })
                },
            ]
        },
        output: {
            path: config.targetDir,
            filename: "[name].js"
        },
        entry: {
            app: config.typescript.entry,
        },
    };
    return conf;
}
exports.getBuildConfigPartial = getBuildConfigPartial;
//# sourceMappingURL=webpack.config.build.js.map