"use strict";
var webpack = require("webpack");
var HtmlWebpackPlugin = require("html-webpack-plugin");
var CopyWebpackPlugin = require("copy-webpack-plugin");
var path = require("path");
var awesome_typescript_loader_1 = require("awesome-typescript-loader");
var dll_tags_plugin_1 = require("./plugins/dll-tags.plugin");
var remove_scripts_plugin_1 = require("./plugins/remove-scripts.plugin");
var DllReferencePlugin = webpack.DllReferencePlugin;
var NamedModulesPlugin = webpack.NamedModulesPlugin;
function getDevConfigPartial(config, indexPath, aot, port) {
    var conf = {
        output: {
            path: config.targetDir,
            filename: "[name].js"
        },
        entry: {
            app: [
                "webpack-dev-server/client?http://localhost:" + port + "/",
                config.typescript.entry
            ]
        },
        performance: {
            hints: false
        },
        devtool: "cheap-module-eval-source-map",
        devServer: {
            compress: true,
            port: port,
            historyApiFallback: {
                disableDotRule: true,
            },
            stats: "minimal",
            host: "0.0.0.0",
            watchOptions: {
                aggregateTimeout: 300
            },
            hot: !aot,
            clientLogLevel: "warning"
        },
        module: {
            rules: [
                {
                    test: /\.scss$/,
                    exclude: /\.style\.scss$/,
                    use: [
                        "style-loader",
                        {
                            loader: "css-loader",
                            options: {
                                importLoaders: 1,
                                localIdentName: "[name]"
                            }
                        },
                        {
                            loader: "postcss-loader",
                            options: {
                                config: path.resolve(__dirname, "..", "config")
                            }
                        },
                        {
                            loader: "sass-loader",
                            options: {
                                sourceMap: false,
                                includePaths: config.sass.includePaths,
                                outputStyle: config.sass.outputStyle
                            }
                        },
                        "empty-sass-shim-loader"
                    ]
                }
            ]
        },
        plugins: [
            new HtmlWebpackPlugin({
                template: indexPath
            }),
            new DllReferencePlugin({
                context: ".",
                manifest: require(path.join(config.dllDir, "polyfills.dll.json"))
            }),
            new DllReferencePlugin({
                context: ".",
                manifest: require(path.join(config.dllDir, "vendors.dll.json"))
            }),
            new dll_tags_plugin_1.DllTagPlugin(["polyfills", "vendors"]),
            new awesome_typescript_loader_1.CheckerPlugin(),
            new webpack.HotModuleReplacementPlugin(),
            new CopyWebpackPlugin([
                {
                    from: path.join(config.dllDir, "*.js"),
                    flatten: true
                }
            ]),
            new CopyWebpackPlugin(config.assets.entries),
            new NamedModulesPlugin(),
            new remove_scripts_plugin_1.RemoveScriptsPlugin(config.webpack.ignoreScripts)
        ]
    };
    if (!aot) {
        conf.entry.app.unshift("webpack/hot/only-dev-server");
        conf.module.rules.push({
            test: /\.ts$/,
            use: [
                {
                    loader: "@angularclass/hmr-loader",
                    query: {
                        pretty: true,
                        prod: false
                    }
                },
                {
                    loader: "awesome-typescript-loader",
                    options: {
                        useTranspileModule: !config.typescript.typecheck,
                        transpileOnly: !config.typescript.typecheck,
                        useCache: true
                    }
                },
                "angular2-template-loader?keepUrl=true",
                "angular-router-loader"
            ],
            exclude: [/\.(spec|e2e|d)\.ts$/]
        });
    }
    return conf;
}
exports.getDevConfigPartial = getDevConfigPartial;
//# sourceMappingURL=webpack.config.dev.js.map